summaryrefslogtreecommitdiff
path: root/compiler/coreSyn
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/coreSyn')
-rw-r--r--compiler/coreSyn/CoreArity.hs4
-rw-r--r--compiler/coreSyn/CoreLint.hs2
-rw-r--r--compiler/coreSyn/CoreSyn.hs10
-rw-r--r--compiler/coreSyn/CoreTidy.hs4
-rw-r--r--compiler/coreSyn/CoreUtils.hs4
5 files changed, 12 insertions, 12 deletions
diff --git a/compiler/coreSyn/CoreArity.hs b/compiler/coreSyn/CoreArity.hs
index 8931725896..d3f24fa7bf 100644
--- a/compiler/coreSyn/CoreArity.hs
+++ b/compiler/coreSyn/CoreArity.hs
@@ -174,13 +174,13 @@ exprArity has the following invariants:
can get "n" manifest lambdas to the top.
Why is this important? Because
- - In TidyPgm we use exprArity to fix the *final arity* of
+ - In GHC.Iface.Tidy we use exprArity to fix the *final arity* of
each top-level Id, and in
- In CorePrep we use etaExpand on each rhs, so that the visible lambdas
actually match that arity, which in turn means
that the StgRhs has the right number of lambdas
-An alternative would be to do the eta-expansion in TidyPgm, at least
+An alternative would be to do the eta-expansion in GHC.Iface.Tidy, at least
for top-level bindings, in which case we would not need the trim_arity
in exprArity. That is a less local change, so I'm going to leave it for today!
diff --git a/compiler/coreSyn/CoreLint.hs b/compiler/coreSyn/CoreLint.hs
index 7c4137e9b5..21f4fd5c0e 100644
--- a/compiler/coreSyn/CoreLint.hs
+++ b/compiler/coreSyn/CoreLint.hs
@@ -489,7 +489,7 @@ We use this to check all top-level unfoldings that come in from interfaces
We do not need to call lintUnfolding on unfoldings that are nested within
top-level unfoldings; they are linted when we lint the top-level unfolding;
-hence the `TopLevelFlag` on `tcPragExpr` in TcIface.
+hence the `TopLevelFlag` on `tcPragExpr` in GHC.IfaceToCore.
-}
diff --git a/compiler/coreSyn/CoreUtils.hs b/compiler/coreSyn/CoreUtils.hs
index 50fdcd9c7b..cd2221246e 100644
--- a/compiler/coreSyn/CoreUtils.hs
+++ b/compiler/coreSyn/CoreUtils.hs
@@ -2502,9 +2502,9 @@ rhsIsStatic
-> (Name -> Bool) -- Which names are dynamic
-> (LitNumType -> Integer -> Maybe CoreExpr)
-- Desugaring for some literals (disgusting)
- -- C.f. Note [Disgusting computation of CafRefs] in TidyPgm
+ -- C.f. Note [Disgusting computation of CafRefs] in GHC.Iface.Tidy
-> CoreExpr -> Bool
--- It's called (i) in TidyPgm.hasCafRefs to decide if the rhs is, or
+-- It's called (i) in GHC.Iface.Tidy.hasCafRefs to decide if the rhs is, or
-- refers to, CAFs; (ii) in CoreToStg to decide whether to put an
-- update flag on it and (iii) in DsExpr to decide how to expand
-- list literals
diff --git a/compiler/coreSyn/CoreSyn.hs b/compiler/coreSyn/CoreSyn.hs
index 919e2300be..3d2f6be299 100644
--- a/compiler/coreSyn/CoreSyn.hs
+++ b/compiler/coreSyn/CoreSyn.hs
@@ -1278,7 +1278,7 @@ has two major consequences
In contrast, orphans are all fingerprinted together in the
mi_orph_hash field of the ModIface.
- See MkIface.addFingerprints.
+ See GHC.Iface.Utils.addFingerprints.
Orphan-hood is computed
* For class instances:
@@ -1286,8 +1286,8 @@ Orphan-hood is computed
(because it is needed during instance lookup)
* For rules and family instances:
- when we generate an IfaceRule (MkIface.coreRuleToIfaceRule)
- or IfaceFamInst (MkIface.instanceToIfaceInst)
+ when we generate an IfaceRule (GHC.Iface.Utils.coreRuleToIfaceRule)
+ or IfaceFamInst (GHC.Iface.Utils.instanceToIfaceInst)
-}
{-
@@ -1351,7 +1351,7 @@ data CoreRule
ru_auto :: Bool, -- ^ @True@ <=> this rule is auto-generated
-- (notably by Specialise or SpecConstr)
-- @False@ <=> generated at the user's behest
- -- See Note [Trimming auto-rules] in TidyPgm
+ -- See Note [Trimming auto-rules] in GHC.Iface.Tidy
-- for the sole purpose of this field.
ru_origin :: !Module, -- ^ 'Module' the rule was defined in, used
@@ -1447,7 +1447,7 @@ data Unfolding
| BootUnfolding -- ^ We have no information about the unfolding, because
-- this 'Id' came from an @hi-boot@ file.
- -- See Note [Inlining and hs-boot files] in ToIface
+ -- See Note [Inlining and hs-boot files] in GHC.CoreToIface
-- for what this is used for.
| OtherCon [AltCon] -- ^ It ain't one of these constructors.
diff --git a/compiler/coreSyn/CoreTidy.hs b/compiler/coreSyn/CoreTidy.hs
index 7642606813..5183d26622 100644
--- a/compiler/coreSyn/CoreTidy.hs
+++ b/compiler/coreSyn/CoreTidy.hs
@@ -4,7 +4,7 @@
This module contains "tidying" code for *nested* expressions, bindings, rules.
-The code for *top-level* bindings is in TidyPgm.
+The code for *top-level* bindings is in GHC.Iface.Tidy.
-}
{-# LANGUAGE CPP #-}
@@ -229,7 +229,7 @@ tidyUnfolding tidy_env
= seqIt $ unf { uf_tmpl = tidyExpr tidy_env unf_rhs } -- Preserves OccInfo
-- This seqIt avoids a space leak: otherwise the uf_is_value,
-- uf_is_conlike, ... fields may retain a reference to the
- -- pre-tidied expression forever (ToIface doesn't look at them)
+ -- pre-tidied expression forever (GHC.CoreToIface doesn't look at them)
| otherwise
= unf_from_rhs